from .models import Role
from flask_migrate import upgrade


def register(app):
    @app.cli.command()
    def deploy():
        """Run deployment tasks."""
        # migrate database to latest revision
        upgrade()
        # create or update user roles
        Role.insert_roles()

    @app.cli.group()
    def daemon():
        """Daemon commands."""
        pass

    @daemon.command('run')
    def run_daemon():
        """Run daemon"""
        from app.daemon import Daemon
        daemon = Daemon()
        daemon.run()

    @app.cli.group()
    def test():
        """Test commands."""
        pass

    @test.command('run')
    def run_test():
        """Run unit tests."""
        import unittest
        tests = unittest.TestLoader().discover('tests')
        unittest.TextTestRunner(verbosity=2).run(tests)
