class JobDisplay extends RessourceDisplay {
  constructor(displayElement) {
    super(displayElement);
    this.jobId = displayElement.dataset.jobId;
    this.user.eventListeners.job.addEventListener((eventType, payload) => this.eventHandler(eventType, payload), this.jobId);
  }

  init(job) {
    this.setCreationDate(this.user.data.jobs[this.jobId].creation_date);
    this.setEndDate(this.user.data.jobs[this.jobId].creation_date);
    this.setDescription(this.user.data.jobs[this.jobId].description);
    this.setService(this.user.data.jobs[this.jobId].service);
    this.setServiceArgs(this.user.data.jobs[this.jobId].service_args);
    this.setServiceVersion(this.user.data.jobs[this.jobId].service_version);
    this.setStatus(this.user.data.jobs[this.jobId].status);
    this.setTitle(this.user.data.jobs[this.jobId].title);
  }

  patch(patch) {
    let re;
    for (let operation of patch) {
      switch(operation.op) {
        case 'replace':
          // Matches: /jobs/{this.user.data.jobs[this.jobId].id}/status
          re = new RegExp('^/jobs/' + this.user.data.jobs[this.jobId].id + '/end_date');
          if (re.test(operation.path)) {this.setEndDate(operation.value); break;}
          // Matches: /jobs/{this.user.data.jobs[this.jobId].id}/status
          re = new RegExp('^/jobs/' + this.user.data.jobs[this.jobId].id + '/status$');
          if (re.test(operation.path)) {this.setStatus(operation.value); break;}
          break;
        default:
          break;
      }
    }
  }

  setTitle(title) {
    for (let element of this.displayElement.querySelectorAll('.job-title')) {this.setElement(element, title);}
  }

  setDescription(description) {
    for (let element of this.displayElement.querySelectorAll('.job-description')) {this.setElement(element, description);}
  }

  setStatus(status) {
    for (let element of this.displayElement.querySelectorAll('.job-status')) {
      this.setElement(element, status);
    }
    for (let element of this.displayElement.querySelectorAll('.status')) {element.dataset.status = status;}
    for (let element of this.displayElement.querySelectorAll('.status-spinner')) {
      if (['complete', 'failed'].includes(status)) {
        element.classList.add('hide');
      } else {
        element.classList.remove('hide');
      }
    }
    for (let element of this.displayElement.querySelectorAll('.restart-job-trigger')) {
      if (['complete', 'failed'].includes(status)) {
        element.classList.remove('hide');
      } else {
        element.classList.add('hide');
      }
    }
  }

  setCreationDate(iso8601CreationDate) {
    let creationDate = new Date(iso8601CreationDate).toLocaleString("en-US");
    for (let element of this.displayElement.querySelectorAll('.job-creation-date')) {this.setElement(element, creationDate);}
  }

  setEndDate(iso8601EndDate) {
    let endDate = new Date(iso8601EndDate).toLocaleString("en-US");
    for (let element of this.displayElement.querySelectorAll('.job-end-date')) {this.setElement(element, endDate);}
  }

  setService(service) {
    for (let element of this.displayElement.querySelectorAll('.job-service')) {this.setElement(element, service);}
  }

  setServiceArgs(serviceArgs) {
    for (let element of this.displayElement.querySelectorAll('.job-service-args')) {this.setElement(element, serviceArgs);}
  }

  setServiceVersion(serviceVersion) {
    for (let element of this.displayElement.querySelectorAll('.job-service-version')) {this.setElement(element, serviceVersion);}
  }
}
